# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import


from ._models import (  # type: ignore
    AcsChatChannel,
    AlexaChannel,
    AlexaChannelProperties,
    Bot,
    BotChannel,
    BotProperties,
    Channel,
    ChannelSettings,
    CheckNameAvailabilityRequestBody,
    CheckNameAvailabilityResponseBody,
    ConnectionSetting,
    ConnectionSettingParameter,
    ConnectionSettingProperties,
    CreateEmailSignInUrlResponse,
    CreateEmailSignInUrlResponseProperties,
    DirectLineChannel,
    DirectLineChannelProperties,
    DirectLineSite,
    DirectLineSpeechChannel,
    DirectLineSpeechChannelProperties,
    EmailChannel,
    EmailChannelProperties,
    Error,
    ErrorAdditionalInfo,
    ErrorBody,
    ErrorDetail,
    ErrorResponse,
    FacebookChannel,
    FacebookChannelProperties,
    FacebookPage,
    HostSettingsResponse,
    KikChannel,
    KikChannelProperties,
    LineChannel,
    LineChannelProperties,
    LineRegistration,
    ListChannelWithKeysResponse,
    M365Extensions,
    MsTeamsChannel,
    MsTeamsChannelProperties,
    NetworkSecurityPerimeter,
    NetworkSecurityPerimeterConfiguration,
    NetworkSecurityPerimeterConfigurationProperties,
    NspAccessRule,
    NspAccessRuleProperties,
    NspAccessRulePropertiesSubscriptionsItem,
    Omnichannel,
    OperationDisplayInfo,
    OperationEntity,
    OperationResultsDescription,
    OutlookChannel,
    PrivateEndpoint,
    PrivateEndpointConnection,
    PrivateEndpointConnectionProperties,
    PrivateLinkResource,
    PrivateLinkResourceBase,
    PrivateLinkResourceListResult,
    PrivateLinkResourceProperties,
    PrivateLinkServiceConnectionState,
    Profile,
    ProvisioningIssue,
    ProvisioningIssueProperties,
    ProxyResource,
    QnAMakerEndpointKeysRequestBody,
    QnAMakerEndpointKeysResponse,
    Resource,
    ResourceAssociation,
    SearchAssistant,
    ServiceProvider,
    ServiceProviderParameter,
    ServiceProviderParameterMetadata,
    ServiceProviderParameterMetadataConstraints,
    ServiceProviderProperties,
    ServiceProviderResponseList,
    Site,
    SiteInfo,
    Sku,
    SkypeChannel,
    SkypeChannelProperties,
    SlackChannel,
    SlackChannelProperties,
    SmsChannel,
    SmsChannelProperties,
    SystemData,
    TelegramChannel,
    TelegramChannelProperties,
    TelephonyChannel,
    TelephonyChannelProperties,
    TelephonyChannelResourceApiConfiguration,
    TelephonyPhoneNumbers,
    WebChatChannel,
    WebChatChannelProperties,
    WebChatSite,
)

from ._enums import (  # type: ignore
    AccessMode,
    ChannelName,
    CreatedByType,
    EmailChannelAuthMethod,
    Key,
    Kind,
    MsaAppType,
    NspAccessRuleDirection,
    OperationResultStatus,
    PrivateEndpointConnectionProvisioningState,
    PrivateEndpointServiceConnectionStatus,
    ProvisioningState,
    PublicNetworkAccess,
    RegenerateKeysChannelName,
    Severity,
    SkuName,
    SkuTier,
)
from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "AcsChatChannel",
    "AlexaChannel",
    "AlexaChannelProperties",
    "Bot",
    "BotChannel",
    "BotProperties",
    "Channel",
    "ChannelSettings",
    "CheckNameAvailabilityRequestBody",
    "CheckNameAvailabilityResponseBody",
    "ConnectionSetting",
    "ConnectionSettingParameter",
    "ConnectionSettingProperties",
    "CreateEmailSignInUrlResponse",
    "CreateEmailSignInUrlResponseProperties",
    "DirectLineChannel",
    "DirectLineChannelProperties",
    "DirectLineSite",
    "DirectLineSpeechChannel",
    "DirectLineSpeechChannelProperties",
    "EmailChannel",
    "EmailChannelProperties",
    "Error",
    "ErrorAdditionalInfo",
    "ErrorBody",
    "ErrorDetail",
    "ErrorResponse",
    "FacebookChannel",
    "FacebookChannelProperties",
    "FacebookPage",
    "HostSettingsResponse",
    "KikChannel",
    "KikChannelProperties",
    "LineChannel",
    "LineChannelProperties",
    "LineRegistration",
    "ListChannelWithKeysResponse",
    "M365Extensions",
    "MsTeamsChannel",
    "MsTeamsChannelProperties",
    "NetworkSecurityPerimeter",
    "NetworkSecurityPerimeterConfiguration",
    "NetworkSecurityPerimeterConfigurationProperties",
    "NspAccessRule",
    "NspAccessRuleProperties",
    "NspAccessRulePropertiesSubscriptionsItem",
    "Omnichannel",
    "OperationDisplayInfo",
    "OperationEntity",
    "OperationResultsDescription",
    "OutlookChannel",
    "PrivateEndpoint",
    "PrivateEndpointConnection",
    "PrivateEndpointConnectionProperties",
    "PrivateLinkResource",
    "PrivateLinkResourceBase",
    "PrivateLinkResourceListResult",
    "PrivateLinkResourceProperties",
    "PrivateLinkServiceConnectionState",
    "Profile",
    "ProvisioningIssue",
    "ProvisioningIssueProperties",
    "ProxyResource",
    "QnAMakerEndpointKeysRequestBody",
    "QnAMakerEndpointKeysResponse",
    "Resource",
    "ResourceAssociation",
    "SearchAssistant",
    "ServiceProvider",
    "ServiceProviderParameter",
    "ServiceProviderParameterMetadata",
    "ServiceProviderParameterMetadataConstraints",
    "ServiceProviderProperties",
    "ServiceProviderResponseList",
    "Site",
    "SiteInfo",
    "Sku",
    "SkypeChannel",
    "SkypeChannelProperties",
    "SlackChannel",
    "SlackChannelProperties",
    "SmsChannel",
    "SmsChannelProperties",
    "SystemData",
    "TelegramChannel",
    "TelegramChannelProperties",
    "TelephonyChannel",
    "TelephonyChannelProperties",
    "TelephonyChannelResourceApiConfiguration",
    "TelephonyPhoneNumbers",
    "WebChatChannel",
    "WebChatChannelProperties",
    "WebChatSite",
    "AccessMode",
    "ChannelName",
    "CreatedByType",
    "EmailChannelAuthMethod",
    "Key",
    "Kind",
    "MsaAppType",
    "NspAccessRuleDirection",
    "OperationResultStatus",
    "PrivateEndpointConnectionProvisioningState",
    "PrivateEndpointServiceConnectionStatus",
    "ProvisioningState",
    "PublicNetworkAccess",
    "RegenerateKeysChannelName",
    "Severity",
    "SkuName",
    "SkuTier",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()
