# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import

from ._operations import Operations  # type: ignore
from ._operations import BotsOperations  # type: ignore
from ._operations import PrivateEndpointConnectionsOperations  # type: ignore
from ._operations import NetworkSecurityPerimeterConfigurationsOperations  # type: ignore
from ._operations import EmailOperations  # type: ignore
from ._operations import PrivateLinkResourcesOperations  # type: ignore
from ._operations import ChannelsOperations  # type: ignore
from ._operations import DirectLineOperations  # type: ignore
from ._operations import BotConnectionOperations  # type: ignore
from ._operations import QnAMakerEndpointKeysOperations  # type: ignore
from ._operations import HostSettingsOperations  # type: ignore
from ._operations import OperationResultsOperations  # type: ignore

from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "Operations",
    "BotsOperations",
    "PrivateEndpointConnectionsOperations",
    "NetworkSecurityPerimeterConfigurationsOperations",
    "EmailOperations",
    "PrivateLinkResourcesOperations",
    "ChannelsOperations",
    "DirectLineOperations",
    "BotConnectionOperations",
    "QnAMakerEndpointKeysOperations",
    "HostSettingsOperations",
    "OperationResultsOperations",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()
